
PauliCirc
=========

A library for the creation of circuits of Pauli gadgets.

GitHub repo: https://github.com/neverlocal/paulicirc


.. toctree::
    :maxdepth: 3
    :caption: Contents

    getting-started

.. include:: api-toc.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
